@@ -1073,15 +1073,25 @@ class ServiceStub(ABC):
         )
         # TODO 优化URL获取通过r.request.url,但也不一定是对的
         logger.info(f'[请求cookies]:{r.request.headers._store.get("cookie")}')
-        logger.info(f'[请求headers]:{r.request.headers}')
+        logger.info(f'[请求headers]:{r.request.headers.get("x1-bilispy-color")}')
         
-        logger.info(f'[响应结果]:{r.json()}')
+        try:
+            r_data = r.json()
+        except Exception:
+            r_data = r.text
+        
+        logger.info(f'[响应结果]:{r_data}')
         logger.info(f'[响应http_code]:{r.status_code}')
         logger.info(f'[响应耗时]:{r.elapsed.total_seconds()}秒')
         logger.info(f'[X-Trace-Id]:{r.headers.get("X-Trace-Id")}')
         # logger.info(f'[响应cookies]:{r.cookies}')
         response.__dict__.update(r.__dict__)
-        response.from_json(r.content)
+        
+        if isinstance(r_data, (str, bytes)) and r.ok:
+            response.code = 0
+            response.msg = 'SUCCESS'
+        else:
+            response.from_json(r.content)
 
 
 class TwirpException(httplib.HTTPException):
